@@ -6,9 +6,10 @@ pub use rtc_connection::RtcConnection;
 mod rtc_channel;
 pub use rtc_channel::RtcChannel;
 
+pub use webrtc::{peer_connection::configuration::RTCConfiguration, ice_transport::ice_server::RTCIceServer};
+
 #[cfg(any(feature = "test", test))]
 pub mod utils;
 
 // Next:
 // - implement `disconnect()` method
-// - move connection and channel traits to `connection-utils`
